@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHOR:  Colin Perkins / Orion Hodson
  *
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:50 $
+ * $Revision: 1.2 $
+ * $Date: 1998/09/22 10:53:49 $
  *
  * Copyright (c) 1996,1997 University College London
  * All rights reserved.
@@ -45,7 +45,7 @@
 #include "bat_include.h"
 #ifdef FreeBSD
 
-#include <sys/soundcard.h>
+#include <machine/soundcard.h>
 
 int          can_read  = FALSE;
 int          can_write = FALSE;
@@ -82,12 +82,6 @@ audio_open_rw(char rw)
 
   audio_fd = open("/dev/audio", rw | O_NDELAY);
   if (audio_fd > 0) {
-    if (ioctl(audio_fd, SNDCTL_DSP_SETDUPLEX, 0) == -1) {
-      /* Cannot enable full-duplex mode. Oh well. */
-#ifdef DEBUG
-            printf("Cannot set full-duplex.\n");
-#endif
-    }
     if (ioctl(audio_fd, SNDCTL_DSP_SETFRAGMENT, &frag) == -1) {
 #ifdef DEBUG
       printf("Cannot set fragment size (ignored)\n");
@@ -164,19 +158,23 @@ audio_duplex(int audio_fd)
    * be open to do this, so if we're passed -1 as a file-descriptor we open
    * the device, do the ioctl, and then close it again...
    */
-  if (audio_fd == -1) {
-    audio_fd = audio_open_rw(O_RDONLY);
-    if (ioctl(audio_fd, SNDCTL_DSP_SETDUPLEX, 0) == -1) {
-      audio_close(audio_fd);
-      return FALSE;
-    }
-    audio_close(audio_fd);
-    return TRUE;
-  }
-  if (ioctl(audio_fd, SNDCTL_DSP_SETDUPLEX, 0) == -1) {
-    return FALSE;
-  }
-  return TRUE;
+        snd_chan_param scp;
+        if (audio_fd == -1) {
+                audio_fd = audio_open_rw(O_RDONLY);
+                ioctl(audio_fd, AIOGFMT, &scp);
+                if ((scp.play_format & AFMT_FULLDUPLEX) == 0) {
+                        audio_close(audio_fd);
+                        return FALSE;
+                }
+                audio_close(audio_fd);
+                return TRUE;
+        }
+        scp.play_format |= AFMT_FULLDUPLEX;
+        scp.rec_format  |= AFMT_FULLDUPLEX;
+        if (ioctl(audio_fd, AIOSFMT, 0) == -1) {
+                return FALSE;
+        }
+        return TRUE;
 }
 
 /* Gain and volume values are in the range 0 - MAX_AMP */
