@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHOR:  Isidor Kouvelas
  *
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:44 $
+ * $Revision: 1.4 $
+ * $Date: 1999/02/05 16:53:52 $
  *
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -125,7 +125,13 @@ void	pcmu_linear_init(void);
 extern short mulawtolin[256];
 extern unsigned char lintomulaw[65536];
 #define s2u(x)	lintomulaw[((unsigned short)(x)) & 0xffff]
-#define u2s(x)	mulawtolin[x]
+#define u2s(x)	mulawtolin[(x)]
+
+extern short         alaw2lin[256];
+extern unsigned char lin2alaw[8192];
+
+#define s2a(x) lin2alaw[(((unsigned short)(x))>>3)]
+#define a2s(x) alaw2lin[(x)]
 
 #endif /* _RAT_AUDIO_H_ */
 
