@@ -1,15 +1,15 @@
 /*
  * FILE:     audio_mix.c
  * PROGRAM:  RAT
- * AUTHOR:   Isidor Kouvelas
+ * AUTHOR:   Isidor Kouvelas / Orion Hodson (MMX)
  * MODIFIED: V.J.Hardman + Colin Perkins
  *
  * These functions taken from audio.c revision 1.4, since they caused
  * problems for the mixer if left in that file. Probably we should 
  * move them into mix.[ch] at some stage in the future...
  *
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:48 $
+ * $Revision: 1.2 $
+ * $Date: 1999/02/10 12:50:25 $
  *
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -50,20 +50,66 @@
 void
 mix_audio(int16 *v0, int16 *v1, size_t len)
 {
-	int i, tmp;
+	int16 *v0e = v0 + len;
+	int tmp;
 
 	assert(v0 != NULL);
 	assert(v1 != NULL);
 
-	for (i = 0;i<len;i++) {
-		tmp = v0[i]+v1[i];
+	while(v0 != v0e) {
+		tmp = *v0 + *v1++;
 		if (tmp>32767) {
 			tmp = 32767;
 		} else if (tmp<-32768) {
 			tmp = -32768;
 		}
-		v0[i] = tmp;
+		*v0++ = tmp;
 	}
 }
 
+#ifdef WIN32
 
+/* For type mix unit size this function is twice as fast
+ * as non-mmx function.  For longer buffers it gets better.
+ */
+
+void 
+mmx_mix_audio(int16 *v0,  int16 *v1, size_t len)
+{
+	unsigned int tmp, endq, i;
+
+	/* The end of where we can do quad sample addition */
+	endq  = ((len * sizeof(short)) / 4) * 4;
+
+	__asm {
+		mov esi, 0
+		mov eax, v0
+		mov ebx, v1
+		jmp START_L1
+LOOP_L1:
+		add esi, 8
+START_L1:
+		movq   mm0, [eax + esi]
+		paddsw mm0, [ebx + esi]
+		movq   [eax + esi], mm0
+		cmp	   esi, endq
+		jb	   LOOP_L1	
+	/* Clear state */
+		emms
+	}
+
+	/* This is not the most efficient mix but setup for more efficient mix
+	 * from here is almost certainly more inefficient.
+	 */
+	for (i = endq / 2; i < len; i++) {
+		tmp = v0[i] + v1[i];
+		if (tmp > 32767) {
+			tmp = 32767;
+		} else if (tmp < -32767) {
+			tmp = -32767;
+		}
+		v0[i] = (short)tmp;
+	}
+}
+
+#endif /* WIN32 */
