@@ -4,8 +4,8 @@
  * AUTHOR:   Isidor Kouvelas
  * MODIFIED: V.J.Hardman
  *
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:48 $
+ * $Revision: 1.2 $
+ * $Date: 1999/02/10 12:50:25 $
  *
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -41,5 +41,9 @@
  * SUCH DAMAGE.
  */
 
-void mix_audio(  int16 *v0,  int16 *v1, size_t len);
+void mix_audio(int16 *v0,  int16 *v1, size_t len);
 
+#ifdef WIN32
+/* GAS does not support mmx for Linux and FreeBSD yet :-( */
+void mmx_mix_audio(int16 *v0,  int16 *v1, size_t len);
+#endif WIN32
\ No newline at end of file
