@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHOR:  Isidor Kouvelas + Orion Hodson
  * 
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:48 $
+ * $Revision: 1.3 $
+ * $Date: 1999/02/05 16:53:52 $
  * 
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -195,6 +195,14 @@ decode_unit(rx_queue_element_struct *u)
 			sc++;
 		}
 		break;
+	case PCMA:
+                d = u->decomp_data = (sample*)block_alloc(BYTES_PER_SAMPLE * SAMPLES_PER_UNIT);
+		sc = (u_char *)u->comp_data[0];
+		for(i = 0; i < SAMPLES_PER_UNIT; i++) {
+			*d++ =(sample)a2s(*sc);
+			sc++;
+		}
+		break;
 	case DVI_WITH_STATE:
 		((struct adpcm_state *)u->comp_data[0])->valprev = ntohs(((struct adpcm_state *)u->comp_data[0])->valprev);
 		memcpy(&u->dbe_source[0]->dvi_state, u->comp_data[0], DVI_STATE_SIZE);
