@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHOR:  I.Kouvelas + V.J.Hardman
  * 
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:48 $
+ * $Revision: 1.3 $
+ * $Date: 1999/02/05 02:15:14 $
  *
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -59,15 +59,28 @@ l16_encoding(sample *data, coded_unit *c)
 static void
 pcm_encoding(sample *data, coded_unit *c)
 {
-	u_char *p;
-	int i;
+	u_char *p, *pend;
 
 	p = c->data = block_alloc(SAMPLES_PER_UNIT);
 	c->data_len = SAMPLES_PER_UNIT;
-	for (i = 0; i < SAMPLES_PER_UNIT; i++)
+        pend = c->data_len + p;
+        while(p != pend)
 		*p++ = lintomulaw[(unsigned short)*data++];
 }
 
+static void
+pcma_encoding(sample *data, coded_unit *c)
+{
+	u_char *p, *pend;
+
+	p = c->data = block_alloc(SAMPLES_PER_UNIT);
+	c->data_len = SAMPLES_PER_UNIT;
+        pend = p + c->data_len;
+        while(p != pend) {
+		*p++ = s2a(*data++);
+        }
+}
+
 static void
 dvi_encoding(sample *data, coded_unit *c, struct adpcm_state *state)
 {
@@ -123,6 +136,9 @@ encoder(session_struct *sp, sample *data, int coding, coded_unit *c)
 	case PCM:
 		pcm_encoding(data, c);
 		break;
+        case PCMA:
+		pcma_encoding(data, c);
+		break;
 	case DVI:
 		dvi_encoding(data, c, &sp->adpcm_state);
 		break;
@@ -147,7 +163,9 @@ get_coding_name(int coding)
 	case WBS:
 		return "WBS";
 	case PCM:
-		return "PCM (mu-law)";
+		return "Mu-law (PCM)";
+	case PCMA:
+		return "A-law (PCM)";
 	case DVI:
 		return "DVI";
 	case LPC:
