@@ -3,8 +3,8 @@
  *
  *  Machine/operating-system specific definitions and includes for RAT.
  *  
- *  $Revision: 1.1.1.1 $
- *  $Date: 1998/08/15 19:16:46 $
+ *  $Revision: 1.3 $
+ *  $Date: 1999/01/27 17:38:39 $
  *
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -47,7 +47,7 @@
 #define OSNAME "FreeBSD"
 #include <unistd.h>
 #include <stdlib.h>
-#include <sys/soundcard.h>
+#include <machine/soundcard.h>
 #define DIFF_BYTE_ORDER  1
 #define AUDIO_SPEAKER    0
 #define AUDIO_HEADPHONE  1
@@ -146,7 +146,8 @@ int gethostname(char *hostname, size_t size);
 #define DIFF_BYTE_ORDER	1
 
 #include <time.h>		/* For clock_t */
-#include <winsock.h>
+#include <winsock2.h>
+#include <ws2tcpip.h>
 
 #define inline
      
