@@ -3,8 +3,8 @@
  * PROGRAM: Rat
  * AUTHORS: Vicky Hardman + Isidor Kouvelas + Colin Perkins
  * 
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:46 $
+ * $Revision: 1.3 $
+ * $Date: 1999/02/27 07:48:59 $
  * 
  * Copyright (c) 1995,1996,1997 University College London
  * All rights reserved.
@@ -57,6 +57,7 @@ init_session(session_struct *sp)
 	thread_pri = 0;	/* Don't nobble priority of this thread - unnecessary! */
 
 	sp->ui				=0;
+
 	sp->mode         		= AUDIO_TOOL;	
 	sp->cur_time			= 0;		/* Should be random */
 	sp->net_maddress		= 0;		/* Same as above, can be used in a sendto */
@@ -185,21 +186,21 @@ parse_options_common(int argc, char *argv[], session_struct *sp[], int sp_size)
 				}
 				i++;
 			}
-			if ((strcmp(argv[i], "-drop") == 0) && (argc > i+1)) {
 			if ((strcmp(argv[i], "-smallui")==0)) {
 				sp[s]->ui = 1;	/* Small */
 				argv[i] = "";
 				i++;
 			}
-                        	sp[s]->drop = atof(argv[++i]);
-                        	if (sp[s]->drop > 1.0) {
-                                	sp[s]->drop = sp[s]->drop/100;
-                        	}
-				i++;
-                	}
-                	if (strcmp(argv[i], "-seed") == 0) {
-                        	srand48(atoi(argv[++i]));
-                	}
+			if ((strcmp(argv[i], "-drop") == 0) && (argc > i+1)) {
+                   	sp[s]->drop = atof(argv[++i]);
+                   	if (sp[s]->drop > 1.0) {
+                         	sp[s]->drop = sp[s]->drop/100;
+                   	}
+			i++;
+           	}
+            if (strcmp(argv[i], "-seed") == 0) {
+                    srand48(atoi(argv[++i]));
+            }
 			if ((strcmp(argv[i], "-pt") == 0) && (argc > i+1)) {
                 		/* Dynamic payload type mapping. Format: "-pt pt/codec/clock/channels" */
 				/* pt/codec must be specified. clock and channels are optional.        */
@@ -315,11 +316,11 @@ void
 parse_options_flakeaway(int argc, char *argv[], session_struct *sp)
 {
 	/* Parse command-line options specific to the flakeaway */
-	if ((sp->in_file = fopen(argv[argc-2],"r")) == NULL) {
+	if ((sp->in_file = fopen(argv[argc-2],"rb")) == NULL) {
 		fprintf(stderr, "Could not open %s\n", argv[argc-2]);
 		exit(1);
 	}
-	if ((sp->out_file = fopen(argv[argc-1],"w")) == NULL) {
+	if ((sp->out_file = fopen(argv[argc-1],"wb")) == NULL) {
 		fprintf(stderr, "Could not open %s\n", argv[argc-1]);
 		exit(1);
 	}
