@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHORS: Vicky Hardman + Isidor Kouvelas + Colin Perkins
  * 
- * $Revision: 1.2 $
- * $Date: 1998/08/15 19:39:11 $
+ * $Revision: 1.4 $
+ * $Date: 1998/12/03 18:09:34 $
  * 
  * Copyright (c) 1995,1996,1997 University College London
  * All rights reserved.
@@ -115,8 +115,10 @@ main(int argc, char *argv[])
 	receive_buffer[0].last_to_get = NULL;
 	receive_buffer[1].last_to_get = NULL;
 	receive_buffer[0].len = 0;
+
 	receive_buffer[1].len = 0;
 
+
 	for (i=0;i<2;i++) {
 		sp[i] = (session_struct *) xmalloc(sizeof(session_struct));
 		init_session(sp[i]);
@@ -131,17 +133,23 @@ main(int argc, char *argv[])
 	/* First, fill in the username.....                                                           */
 #ifdef WIN32
 	if (!GetUserName(user, &size)) {
+
 		uname = "UNKNOWN";
+
 	} else {
+
 		uname=(char*)user;
+
 	}
 #else 		/* ...it's a unix machine... */
 	pwent = getpwuid(getuid());
 	uname = pwent->pw_name;
 #endif
 
+
 		sprintf(cname, "%s@", uname);
 	
+
 	/* Now the hostname. Must be FQDN or dotted-quad IP address (RFC1889) */
 	hname = cname + strlen(cname);
 	if (gethostname(hname, MAXHOSTNAMELEN) != 0) {
@@ -298,7 +306,8 @@ main(int argc, char *argv[])
 	
 			if (power_time > 400) {
 				if (sp[i]->sending_audio) {
-					lbl_cb_send_power(sp[i],cname, sp[i]->rb.silence_ptr->prev->energy);
+					/* send power message if using smallui */
+					if (sp[i]->ui) lbl_cb_send_power(sp[i], cname, sp[i]->rb.silence_ptr->prev->energy);
 					if (sp[i]->meter && sp[i]->ui_on)
 						ui_input_level(log10((double)1.0 + (double)sp[i]->rb.silence_ptr->prev->energy / (double)127) * 67);
 					if (sp[i]->rb.talkspurt && sp[i]->ui_on) {
@@ -310,6 +319,7 @@ main(int argc, char *argv[])
 						sp[i]->lecture = FALSE;
 						update_lecture_mode(sp[i]);
 					} else
+						if (sp[i]->ui) lbl_cb_send_power(sp[i], cname, 0);
 						ui_info_deactivate_us();
 				}
 				power_time = 0;
