@@ -1,10 +1,10 @@
 /*
  * FILE: mix.c
  * PROGRAM: RAT/Mixer
- * AUTHOR: Isidor Kouvelas + Colin Perkins
+ * AUTHOR: Isidor Kouvelas + Orion Hodson + Colin Perkins
  *
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:45 $
+ * $Revision: 1.2 $
+ * $Date: 1999/02/10 12:50:25 $
  *
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -51,6 +51,58 @@
  * We allocate space three time the requested one so that we
  * dont have to copy everything when we hit the boundaries..
  */
+
+typedef void (*mix_f)(sample *buf, sample *incoming, size_t len);
+
+static mix_f mix_fn;
+
+#ifdef WIN32
+
+/* CheckMMXTechnology is (C) Intel 1998 */
+static BOOL 
+CheckMMXTechnology(void)
+{
+
+	BOOL retval = TRUE;
+
+	DWORD RegEDX;
+
+
+	__try {
+		_asm {
+			mov eax, 1	// set up CPUID to return processor version and features
+
+					//	0 = vendor string, 1 = version info, 2 = cache info
+
+			CPUID           // code bytes = 0fh,  0a2h
+			mov RegEDX, edx	// features returned in edx
+	   	}
+
+   	} __except(EXCEPTION_EXECUTE_HANDLER) { retval = FALSE; }
+
+
+	if (retval == FALSE)
+		return FALSE;        	// processor does not support CPUID
+
+	if (RegEDX & 0x800000) 		// bit 23 is set for MMX technology
+	{
+	   __try { _asm emms } 		// try executing the MMX instruction "emms"
+
+	   __except(EXCEPTION_EXECUTE_HANDLER) { retval = FALSE; }
+
+	} else {
+		return FALSE;        	// processor supports CPUID but does not support MMX technology
+	}
+
+
+	// if retval == 0 here, it means the processor has MMX technology but
+
+	// floating-point emulation is on; so MMX technology is unavailable
+
+	return retval;
+}
+#endif /* WIN32 */
+
 mix_struct *
 init_mix(session_struct *sp, int buffer_length)
 {
@@ -62,6 +114,15 @@ init_mix(session_struct *sp, int buffer_length)
 	ms->mix_buffer = (sample *)xmalloc(3 * buffer_length * BYTES_PER_SAMPLE);
 	audio_zero(ms->mix_buffer, 3*buffer_length, DEV_L16);
 	ms->mix_buffer += buffer_length;
+	mix_fn = mix_audio;
+
+#ifdef WIN32
+	if (CheckMMXTechnology()) {
+		printf("MMX Mixer enabled\n");
+		mix_fn = mmx_mix_audio;
+	}
+#endif
+
 	return (ms);
 }
 
@@ -74,13 +135,15 @@ mix_add(mix_struct *ms, sample *buf, int offset, int len)
 	assert(len    <= ms->buf_len);
 	
 	xmemchk();
+
 	if (offset + len > ms->buf_len) {
 		assert((offset + len - ms->buf_len) < ms->buf_len);
-		mix_audio(ms->mix_buffer + offset, buf, ms->buf_len - offset);
-		mix_audio(ms->mix_buffer, buf, offset + len - ms->buf_len);
+		mix_fn(ms->mix_buffer + offset, buf, ms->buf_len - offset);
+		mix_fn(ms->mix_buffer, buf, offset + len - ms->buf_len);
 	} else {
-		mix_audio(ms->mix_buffer + offset, buf, len);
+		mix_fn(ms->mix_buffer + offset, buf, len);
 	}
+
 	xmemchk();
 }
 
