@@ -3,7 +3,7 @@
  * 
  * Modified by Isidor Kouvelas from NT source.
  * 
- * $Revision: 1.2 $ $Date: 1998/08/17 17:08:28 $
+ * $Revision: 1.5 $ $Date: 1999/02/22 13:46:39 $
  * 
  * Modified by V.J.Hardman 2/3/95 All the network specific routines have been
  * moved to this module
@@ -121,9 +121,9 @@ sock_init(u_long inaddr, int port, int t_flag)
 	}
 #endif
 
-	sinme.sin_family = AF_INET;
+	sinme.sin_family      = AF_INET;
 	sinme.sin_addr.s_addr = htonl(INADDR_ANY);
-	sinme.sin_port = htons(port);
+	sinme.sin_port        = htons(port);
 	if (bind(tmp_fd, (struct sockaddr *) & sinme, sizeof(sinme)) < 0) {
 		perror("bind");
 		exit(1);
@@ -138,12 +138,14 @@ sock_init(u_long inaddr, int port, int t_flag)
 
 		if (setsockopt(tmp_fd, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *) &imr, sizeof(struct ip_mreq)) == -1) {
 			fprintf(stderr, "IP multicast join failed!\n");
+			abort();
 		}
 
 		setsockopt(tmp_fd, IPPROTO_IP, IP_MULTICAST_LOOP, &loop, sizeof(loop));
 
-		if (setsockopt(tmp_fd, IPPROTO_IP, IP_MULTICAST_TTL, &ttl, sizeof(ttl)) < 0)
+		if (setsockopt(tmp_fd, IPPROTO_IP, IP_MULTICAST_TTL, (char *) &ttl, sizeof(ttl)) < 0) {
 			perror("setsockopt IP_MULTICAST_TTL");
+		}
 	}
 	return tmp_fd;
 }
@@ -258,7 +260,10 @@ read_net(int fd, u_int32 cur_time, int type, int *nbdecryption)
 void
 read_packets_and_add_to_queue(int fd, u_int32 cur_time, pckt_queue_struct * queue, int type)
 {
-	int             l, nb, nbdecryption;
+#ifndef WIN32
+	int             l, nb;
+#endif
+	int		nbdecryption;
 	pckt_queue_element_struct pckt;
 	pckt_queue_element_struct *pckt_ptr = &pckt;
 
@@ -316,10 +321,12 @@ network_read(session_struct    *session_pointer,
 
 	for (;;) {
 #ifdef WIN32
-                while(is_audio_ready() == FALSE) {
+
+                while(is_audio_ready() == FALSE && session_pointer->mode != TRANSCODER) {
                        Sleep(4);
 		}
 #endif
+
 		FD_ZERO(&rfds);
 		FD_SET(session_pointer->rtp_fd, &rfds);
 		FD_SET(session_pointer->rtcp_fd, &rfds);
