@@ -1,5 +1,5 @@
 #
-# Copyright (c) 1995-98 University College London
+# Copyright (c) 1995-99 University College London
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -46,11 +46,11 @@ option add *Radiobutton*selectColor 	forestgreen
 option add *Checkbutton*selectColor 	forestgreen 
 option add *borderWidth 		1 
 
-set statsfont     -*-courier-medium-r-*-*-12-*-*-*-*-*-iso8859-1
-set titlefont     -*-helvetica-medium-r-normal--14-*-p-*-iso8859-1
-set infofont      -*-helvetica-medium-r-normal--12-*-p-*-iso8859-1
-set smallfont     -*-helvetica-medium-r-normal--10-*-p-*-iso8859-1
-set verysmallfont -*-courier-medium-o-normal--8-*-m-*-iso8859-1
+set statsfont		{courier 8}
+set titlefont		{helvetica 10}
+set infofont		{helvetica 10}
+set smallfont		{helvetica  8}
+set verysmallfont	{helvetica  8}
 
 # app is common rather than rat so info is shared between all win32 mbone apps.
 set V(class) "Mbone Applications"
@@ -196,7 +196,7 @@ frame .l.t -relief raised
 scrollbar .l.t.scr -relief flat -highlightthickness 0 -command ".l.t.list yview"
 canvas .l.t.list -highlightthickness 0 -bd 0 -relief raised -width $iwd -yscrollcommand ".l.t.scr set" -yscrollincrement [expr $ibd + $iht]
 frame .l.s -bd 0
-button .l.s.opts -highlightthickness 0 -padx 0 -pady 0 -text Options -command "wm deiconify .b"
+button .l.s.opts -highlightthickness 0 -padx 0 -pady 0 -text Options -command {wm deiconify .b; raise .b .}
 button .l.s.about -highlightthickness 0 -padx 0 -pady 0 -text About -command {wm deiconify .about}
 button .l.s.quit -highlightthickness 0 -padx 0 -pady 0 -text Quit -command {update; destroy .; update}
 
@@ -348,7 +348,7 @@ frame .b.f.pkt.pr -relief sunken
 pack  .b.f.pkt.pr -side left -fill x
 label .b.f.pkt.pr.l -highlightthickness 0 -justify left -text  "Primary Encoding"
 pack  .b.f.pkt.pr.l -side top -fill both -expand 1
-dropdown .b.f.pkt.pr.dl prenc primary "16-bit linear" "PCM (mu-law)" DVI GSM LPC
+dropdown .b.f.pkt.pr.dl prenc primary "16-bit linear" "Mu-law (PCM)" "A-law" DVI GSM LPC
 pack  .b.f.pkt.pr.dl -side left -fill x -expand 1
 
 # secondary
@@ -356,7 +356,7 @@ frame .b.f.pkt.sec -relief sunken
 pack  .b.f.pkt.sec -side left -fill x
 label .b.f.pkt.sec.l -highlightthickness 0 -justify left -text  "Secondary Encoding"
 pack  .b.f.pkt.sec.l -side top -fill both -expand 1
-dropdown .b.f.pkt.sec.dl secenc redundancy NONE "PCM (mu-law)" DVI GSM LPC
+dropdown .b.f.pkt.sec.dl secenc redundancy NONE "Mu-law (PCM)" "A-law" DVI GSM LPC
 pack  .b.f.pkt.sec.dl -side left -fill x -expand 1
 
 # Local Options
@@ -601,7 +601,7 @@ Science, University College London, UK. The work was supported by projects:
    - Robust Audio Tool (RAT)
 
 Further information is available on the world-wide-web, please access URL:
-http://www-mice.cs.ucl.ac.uk/mice/rat/
+http://www-mice.cs.ucl.ac.uk/multimedia/software/rat/
 
 Please send comments/suggestions/bug-reports to <rat-trap@cs.ucl.ac.uk>
 }
@@ -618,7 +618,7 @@ wm withdraw .copyright
 message   .copyright.m -text {
  Robust-Audio Tool (RAT)
  
- Copyright (C) 1995-98 University College London
+ Copyright (C) 1995-99 University College London
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without
