@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHOR:  Isidor Kouvelas + Orion Hodson
  * 
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:46 $
+ * $Revision: 1.3 $
+ * $Date: 1998/12/21 17:23:01 $
  *
  * Copyright (c) 1995,1996 University College London
  * All rights reserved.
@@ -293,8 +293,12 @@ validate_buffer_length(rx_buffer_struct *buf)
 	char errmsg[80];
 	int count = count_buffer_queue(buf);
 	if (count != buf->len) {
-		sprintf(errmsg,"count (%d) != buf_len (%d)\n", count, buf->len);
+		sprintf(errmsg,"count (%d) != buf_len (%ld)\n", count, buf->len);
+#ifdef WIN32
 		OutputDebugString(errmsg);
+#else
+		printf("%s\n", errmsg);
+#endif
 	}
 #endif
 }
@@ -344,13 +348,6 @@ service_receiver(cushion_struct    *cushion,
 {
 	rx_queue_element_struct *up;
 	rx_interval_struct *ip;
-	int power;
-   	/* Get power for this sample - KH*/
-	if (ms->tail < SAMPLES_PER_UNIT) {
-			power=audio_energy(ms->mix_buffer + ms->buf_len - SAMPLES_PER_UNIT, SAMPLES_PER_UNIT); 
-	} else {
-			power=audio_energy(ms->mix_buffer + ms->tail - SAMPLES_PER_UNIT, SAMPLES_PER_UNIT); 
-	}
         
 	while (receive_queue->queue_empty_flag == FALSE) {
 		up = get_unit_off_rx_queue(receive_queue);
@@ -373,7 +370,7 @@ service_receiver(cushion_struct    *cushion,
 			decode_unit(up);
                         if (up->decomp_data != NULL) {
                                 mix_do_one_chunk(ms, up);
-                                mark_active_senders(up, sp);
+                                mark_active_senders(up, sp, ms);
 				if (!sp->have_device && (audio_device_take(sp) == FALSE)) {
 					lbl_cb_send_request(sp);
 				}
@@ -393,7 +390,7 @@ service_receiver(cushion_struct    *cushion,
                         }
 			if (up->decomp_data != NULL && up->mixed == FALSE) {
 				mix_do_one_chunk(ms, up);
-				mark_active_senders(up, sp);
+				mark_active_senders(up, sp, ms);
 				if (!sp->have_device && (audio_device_take(sp) == FALSE)) {
 					lbl_cb_send_request(sp);
 				}
