@@ -4,8 +4,8 @@
  * Modified: Vicky Hardman + Colin Perkins
  * Purpose:  RTCP protocol routines
  *
- * $Revision: 1.2 $
- * $Date: 1998/08/18 14:17:44 $
+ * $Revision: 1.6 $
+ * $Date: 1999/01/06 16:11:38 $
  *
  * Copyright (c) 1995,1996,1997 University College London
  * All rights reserved.
@@ -150,15 +150,13 @@ rtcp_decode_rtcp_pkt(session_struct *sp, session_struct *sp2, u_int8 *packet, in
 			ssrc = ntohl(pkt->r.sr.ssrc);
 			if ((ssrc == sp->db.myssrc) && sp->filter_loopback) return;
 			dbe = rtcp_getornew_dbentry(sp, ssrc, addr, cur_time);
-			dbe->last_active   = sp->cur_time;
-			dbe->last_sr       = sp->cur_time;
-
-			/* Take note of mapping to use in synchronisation */
 			dbe->mapping_valid = TRUE;
 			dbe->last_ntp_sec  = ntohl(pkt->r.sr.ntp_sec);
 			dbe->last_ntp_frac = ntohl(pkt->r.sr.ntp_frac);
 			dbe->last_rtp_ts   = ntohl(pkt->r.sr.rtp_ts);
-
+			dbe->last_active   = sp->cur_time;
+			dbe->dlsr_base     = sp->cur_time;
+			dbe->last_sr       = ((dbe->last_ntp_sec & 0xffff) << 16) | ((dbe->last_ntp_frac & 0xffff0000) >> 16);
 			break;
 		case RTCP_RR:	/* We won't deal with this just yet */
 			ssrc = ntohl(pkt->r.rr.ssrc);
@@ -479,13 +477,11 @@ rtcp_packet_fmt_addrr(session_struct *sp, u_int8 * ptr, rtcp_dbentry * dbe)
 	}
 
 	rptr->ssrc     = htonl(dbe->ssrc);
-	rptr->loss     = (dbe->lost_frac << 24 | (dbe->lost_tot & 0xffffff));
-	rptr->loss     = htonl(rptr->loss);
-	rptr->last_seq = htons(dbe->cycles + dbe->lastseqno);
+	rptr->loss     = htonl(dbe->lost_frac << 24 | (dbe->lost_tot & 0xffffff));
+	rptr->last_seq = htonl((dbe->cycles << 16) + dbe->lastseqno);
 	rptr->jitter   = htonl((u_long) dbe->jitter);
 	rptr->lsr      = htonl(dbe->last_sr);
-	rptr->dlsr     = sp->cur_time - dbe->last_sr;
-	rptr->dlsr     = htonl(rptr->dlsr);
+	rptr->dlsr     = htonl(((sp->cur_time - dbe->dlsr_base) * 65536) / 8000);
 	return ptr + 24;
 }
 
@@ -559,7 +555,7 @@ u_int32 rtcp_interval(int 	 members,
     /*                                                                */
     /* Time is in 8kHz audio samples! [csp]                           */
 #ifdef DEBUG_RTCP
-    printf("               report_interval=%ld\n", (u_int32) (t * (drand48() + 0.5)) * 8000);
+    printf("               report_interval=%ld (base=%f)\n", (u_int32) (t * (drand48() + 0.5)) * 8000, t * 8000);
 #endif
     return (u_int32) (t * (drand48() + 0.5)) * 8000;
 }
