@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHORS: Colin Perkins + Isidor Kouvelas  
  * 
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:45 $
+ * $Revision: 1.4 $
+ * $Date: 1998/12/03 18:09:35 $
  * 
  * Copyright (c) 1997 University College London
  * All rights reserved.
@@ -49,9 +49,9 @@
 #define GRAY	1
 #define WHITE	2
 
-void mark_active_senders(rx_queue_element_struct *up, session_struct *sp)
+void mark_active_senders(rx_queue_element_struct *up, session_struct *sp, mix_struct *ms)
 {
-	int 	       i;
+	int 	       i, power;
 	speaker_table *st = NULL;
 
 	for (i = 0; i < up->dbe_source_count; i++) {
@@ -74,6 +74,14 @@ void mark_active_senders(rx_queue_element_struct *up, session_struct *sp)
 			}
 		st->state = WHITE;
 	}
+	/* send power message if using smallui */
+	if (sp->ui) {
+		if (ms->tail < SAMPLES_PER_UNIT) 
+			 power=audio_energy(ms->mix_buffer + ms->buf_len - SAMPLES_PER_UNIT, SAMPLES_PER_UNIT); 
+		else power=audio_energy(ms->mix_buffer + ms->tail - SAMPLES_PER_UNIT, SAMPLES_PER_UNIT); 
+		
+		lbl_cb_send_power(sp, st->dbe->sentry->cname, power);
+	}
 }
 
 void clear_active_senders(session_struct *sp)
@@ -90,6 +98,7 @@ void clear_active_senders(session_struct *sp)
 			if (sp->ui_on) {
 				ui_info_gray((*stp)->dbe);
 			}
+			if (sp->ui) lbl_cb_send_power(sp, (*stp)->dbe->sentry->cname, 0);
 			(*stp)->state = GRAY;
 		}
 	}
