@@ -3,8 +3,8 @@
  * PROGRAM: RAT
  * AUTHORS: Colin Perkins + Isidor Kouvelas  
  * 
- * $Revision: 1.1.1.1 $
- * $Date: 1998/08/15 19:16:45 $
+ * $Revision: 1.2 $
+ * $Date: 1998/12/03 12:14:31 $
  * 
  * Copyright (c) 1997 University College London
  * All rights reserved.
@@ -40,6 +40,6 @@
  * SUCH DAMAGE.
  */
 
-void mark_active_senders(rx_queue_element_struct *up, session_struct *sp);
+void mark_active_senders(rx_queue_element_struct *up, session_struct *sp, mix_struct *ms);
 void clear_active_senders(session_struct *sp);
 void check_active_leave(session_struct *sp, rtcp_dbentry *e);
