@@ -3,8 +3,8 @@
  *	PROGRAM: Rat
  *	AUTHOR: Isidor Kouvelas + Colin Perkins + Orion Hodson
  * 	
- *	$Revision: 1.2 $
- * 	$Date: 1998/09/22 08:56:20 $
+ *	$Revision: 1.7 $
+ * 	$Date: 1999/02/27 07:49:00 $
  *
  * Copyright (c) 1995,1996,1997 University College London
  * All rights reserved.
@@ -585,9 +585,12 @@ redun_cmd(ClientData ttp, Tcl_Interp *i, int argc, char *argv[])
 	}
 
 	switch (argv[1][0]) {
-	case 'P':
+	case 'M':
 		encoding = PCM;
 		break;
+	case 'A':
+		encoding = PCMA;
+		break;
 	case 'D':
 		encoding = DVI;
 		break;
@@ -636,9 +639,12 @@ primary_cmd(ClientData ttp, Tcl_Interp *i, int argc, char *argv[])
 	case '1':
 		encoding = L16;
 		break;
-	case 'P':
+	case 'M':
 		encoding = PCM;
 		break;
+	case 'A':
+		encoding = PCMA;
+		break;
 	case 'D':
 		encoding = DVI;
 		break;
@@ -934,7 +940,7 @@ play_file_cmd(ClientData ttp, Tcl_Interp *i, int argc, char *argv[])
 		session_pointer->in_file = NULL;
 	}
 	if (strncmp(argv[1], "stop", 4)) {
-		session_pointer->in_file = fopen(argv[1], "r");
+		session_pointer->in_file = fopen(argv[1], "rb");
 		if (session_pointer->in_file == NULL) {
 			perror("fopen infile");
 		}
@@ -959,7 +965,7 @@ rec_file_cmd(ClientData ttp, Tcl_Interp *i, int argc, char *argv[])
 		session_pointer->out_file = NULL;
 	}
 	if (strncmp(argv[1], "stop", 4)) {
-		session_pointer->out_file = fopen(argv[1], "w");
+		session_pointer->out_file = fopen(argv[1], "wb");
 		if (session_pointer->out_file == NULL) {
 			perror("fopen outfile");
 		}
@@ -1091,10 +1097,6 @@ ui_init(session_struct *session_pointer, int argc, char **argv)
 	Tcl_Init(interp);
 	Tk_Init(interp);
 
-	if (Tcl_VarEval(interp, TCL_LIBS, NULL) != TCL_OK) {
-		fprintf(stderr, "TCL_LIBS error: %s\n", interp->result);
-	}
-
 	Tcl_CreateCommand(interp, "rtcp_name", 		rtcp_name_cmd, 		(ClientData) session_pointer, NULL);
 	Tcl_CreateCommand(interp, "rtcp_email", 	rtcp_email_cmd,		(ClientData) session_pointer, NULL);
 	Tcl_CreateCommand(interp, "rtcp_phone", 	rtcp_phone_cmd,		(ClientData) session_pointer, NULL);
@@ -1124,7 +1126,7 @@ ui_init(session_struct *session_pointer, int argc, char **argv)
 #ifdef WIN32
 	Registry_Init(interp);
 	Tcl_CreateCommand(interp, "puts", WinPutsCmd, (ClientData)session_pointer, NULL);
-    Tcl_CreateCommand(interp, "getusername", WinGetUserName, (ClientData)session_pointer, NULL);
+        Tcl_CreateCommand(interp, "getusername", WinGetUserName, (ClientData)session_pointer, NULL);
 #endif /* WIN32 */
 	Tk_DefineBitmap(interp, Tk_GetUid("ucl"), ucl_bits, ucl_width, ucl_height);
 	Tk_DefineBitmap(interp, Tk_GetUid("mic"), mic_bits, mic_width, mic_height);
@@ -1143,7 +1145,11 @@ ui_init(session_struct *session_pointer, int argc, char **argv)
 
 	sprintf(comm, "set ratversion {%s}", RAT_VERSION);
 	eval_check(interp, comm);
-	eval_check(interp, init_ui_script);
+	if (session_pointer->ui) {
+		eval_check(interp, init_ui_small_script);
+	} else {
+		eval_check(interp, init_ui_script);
+	}
 
 #if !defined(NDEBUG) && !defined(WIN32)
 	sprintf(comm, ".r.b.ucl configure -background salmon");
